# GameKit

## What is this?
This is a python package for game theory-related algorithms.

## How can I install this?
Currently, this repository is under development.

To install:

`pip install gameTheory`

## What do you mean by a library for game theory?
In game theory, we deal with problems like finding equilibrium, evolutionarily stable strategies, stable matching, fair division, bankruptcy, voting, etc. In this package, we are implementing the algorithms proposed for these problems. For example, a function that finds the stable matching for marriage problem with the Gale-Shapley algorithm.

## Can I contribute to this repository?
This package is not limited to one group or university. We would be glad if you contributed to this package even by creating an issue and requesting a new feature. You are always welcome to make a bug report, open an improvement suggestion issue, or send pull requests. Moreover, you can implement the `new feature` issues that [have not been assigned](https://github.com/alifa98/GameKit/issues?q=is%3Aissue+is%3Aopen+no%3Aassignee) and send pull requests.

## What are your references?
Our primary source is  **Game Theory, Alive** book [online version](https://homes.cs.washington.edu/~karlin/GameTheoryBook.pdf)

## How can I contact you?
You can open a new discussion in this repository's `Discussion` section for any question.
https://github.com/alifa98/GameKit/discussions

If you want to contact us by email, you can send your feedback, question, proposal, or requests to ali@faraji.info
